package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````<"D```````!``````````$C1````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````)`9````````D!D`````````
M$`````````$````%`````"``````````(``````````@````````1D,`````
M``!&0P`````````0`````````0````0`````<`````````!P`````````'``
M``````#01@```````-!&`````````!`````````!````!@````#`````````
M`,``````````P````````"`0````````8"``````````$`````````(````&
M````(,`````````@P````````"#`````````P`$```````#``0````````@`
M````````!`````0````X`P```````#@#````````.`,````````P````````
M`#``````````"``````````$````!````&@#````````:`,```````!H`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````,``````````P``````````@`````````4.5T9`0`
M``!PKP```````'"O````````<*\```````#T`````````/0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$`````,``````````P`````````#`````
M`````!``````````$`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````(`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````$````%`````,```!'3E4`&Z>]].P>P/BJP=Z$
M:P(-%2AY;04$````$`````$```!'3E4```````,````"```````````````1
M````1`````0````(````(!`0``5`!(0H`@`$@(8`A(()```)(`0(B(`10;H`
M`@@`````1````$<```!*````2P```%(```!3````5`````````!6````5P``
M`%@```!9````6P```%T``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\
M(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGS[H6Q@:PE#UF>OS&9"
M1=7LB0=PTS-BV^T5C"7,#3J7"WZIG)O19<YMX*<""FL:GE"CX/M)````````
M`````````````````````````````"("```2````````````````````````
M`+@"```2`````````````````````````.@````1````````````````````
M`````)H!```2`````````````````````````*("```2````````````````
M`````````(P````1``````````````````````````D"```2````````````
M`````````````#P!```2`````````````````````````(`"```2````````
M`````````````````,4!```2``````````````````````````$````@````
M`````````````````````%T"```2`````````````````````````&<````2
M`````````````````````````)T"```2`````````````````````````)0`
M```2``````````````````````````("```2````````````````````````
M`%0"```2`````````````````````````*@"```2````````````````````
M`````-(````2`````````````````````````.(````2````````````````
M`````````%(!```2`````````````````````````'`!```2````````````
M`````````````(H````1`````````````````````````'\#```2````````
M`````````````````!`````@`````````````````````````#H"```2````
M`````````````````````"<"```2`````````````````````````+T````2
M`````````````````````````"P````@`````````````````````````)T`
M```2`````````````````````````*L````2````````````````````````
M`"P"```2``````````````````````````<!```2````````````````````
M`````-@!```2`````````````````````````"(!```2````````````````
M`````````$4"```2`````````````````````````(X"```2````````````
M`````````````*\!```2`````````````````````````$,!```2````````
M`````````````````#,!```2`````````````````````````&`!```2````
M`````````````````````'X!```2`````````````````````````!0"```2
M`````````````````````````&@"```2`````````````````````````(4!
M```2`````````````````````````-D"```2````````````````````````
M`'D````2`````````````````````````),!```2````````````````````
M`````(P!```2`````````````````````````)P````2````````````````
M`````````*@!```2`````````````````````````/,````2````````````
M`````````````,0"```2`````````````````````````/8!```2````````
M`````````````````)4"```2`````````````````````````-D````2````
M`````````````````````,0````2`````````````````````````'D"```1
M`````````````````````````.D!```1`````````````````````````*0`
M```2`````````````````````````&@!```2````````````````````````
M`!<!```2`````````````````````````+8!```2````````````````````
M`````%4````2`````````````````````````'<!```2````````````````
M`````````+,````2`````````````````````````&("```2````````````
M`````````````(@#```2`!``,%,````````&`0```````-T#```2`!``T%<`
M``````"""````````&(````2`!``,"<````````R`@```````/\"```2`!``
M@$@````````)`````````!T#```2`!``8&````````!Y`@````````,$```2
M`!``D$@````````2`@```````,,#```0`!H`(-```````````````````!`#
M```2`!``L$H````````E`````````#,#```2`!``$%$```````!\````````
M`)0#```1`!(``'`````````$`````````+`#```2`!``0%0```````"?`0``
M`````+L#```2`!``8$<````````W`````````-@#```0`!H`8.``````````
M`````````/$#```2`!``P%$````````+`0```````*,#```0`!D``-``````
M`````````````%<#```2`!``X$H```````#<`````````.H#```0`!D`(-``
M`````````````````!`$```1`!D`&-`````````(`````````*D#```2`!``
M<"D````````F`````````,\#```2`!``T%(```````!8`````````*4#```@
M`!D``-```````````````````&T#```2`!``D%$````````A`````````$8`
M```B`````````````````````````$$#```2`!``H$<```````#8````````
M`&,#```2`!``X%4```````#K`0```````!H$```2`!``P$L```````!&!0``
M``````!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?7V-X85]F:6YA;&EZ90!?
M7VQI8F-?<W1A<G1?;6%I;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H
M:U]F86EL`%]?96YV:7)O;@!S=')N8VUP`&QS=&%T-C0`86-C97-S`&]P96YD
M:7(`<F5A9&1I<C8T`'-T<FQE;@!?7W-P<FEN=&9?8VAK`'5N;&EN:P!C;&]S
M961I<@!R;61I<@!03%]T:')?:V5Y`'!T:')E861?9V5T<W!E8VEF:6,`8F]O
M=%]$>6YA3&]A9&5R`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!R96%D
M;&EN:P!M96UC:'(`4&5R;%]S=E]S971P=FX`4&5R;%]S=E]S971P=@!M96UM
M;W9E`')E86QL;V,`9V5T<&ED`&UE;6-P>0!S=')C:'(`<W1R9'5P`'-T<G1O
M:P!S=')C;7``7U]S=')N8W!Y7V-H:P!G971U:60`<W1R<W1R`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7V%T9F]R:U]L;V-K`%!,
M7V1O7W5N9'5M<`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S90!P97)L
M7V1E<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?86QL;V,`
M<&5R;%]C;VYS=')U8W0`<&5R;%]R=6X`97AI=`!M:V1I<@!?7V5R<FYO7VQO
M8V%T:6]N`'-T9&5R<@!?7V9P<FEN=&9?8VAK`&]P96XV-`!L<V5E:S8T`')E
M860`8VQO<V4`4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O
M86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T`&QI8G!E<FPN<V\N-2XS-`!L:6)C
M+G-O+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N
M86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A
M<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E
M;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$T`$=,
M24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`1TQ)
M0D-?,BXR+C4`1TQ)0D-?,BXS+C0````!``$``0`"``,``P`!``,``@`!``$`
M`P`$``,``P`#``$``0`#``,``0`#``,``P`!``$``P`#``$`!0`#``$``0`!
M``$``0`#``,``0`#``,``P`!``,``P`!``8``P`#``4``P`'``$``0`#``,`
M`@`#``$``P`#``$``0`'``@``P`#``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``P`!``$``0`````````!``<`]0(``!``
M````````E)&6!@``"``G!```$````+21E@8```<`,@0``!`````4:6D-```&
M`#T$```0````LY&6!@``!0!'!```$````'(9:0D```0`4@0``!````!U&FD)
M```#`%X$```0````=!EI"0```@!J!`````````C0````````"``````````(
MT````````!C0````````"`````````#@<@```````+##````````!@````,`
M`````````````+C#````````!@````8``````````````,##````````!@``
M``H``````````````,C#````````!@````L``````````````-##````````
M!@```!D``````````````-C#````````!@```!T``````````````.##````
M````!@```%H``````````````.C#````````!@```"$``````````````/##
M````````!@```"(``````````````/C#````````!@```#H`````````````
M``#$````````!@```#L```````````````C$````````!@```$``````````
M`````/C!````````!P````$```````````````#"````````!P````(`````
M``````````C"````````!P````0``````````````!#"````````!P````4`
M`````````````!C"````````!P````<``````````````"#"````````!P``
M``@``````````````"C"````````!P````D``````````````##"````````
M!P````P``````````````#C"````````!P````T``````````````$#"````
M````!P````X``````````````$C"````````!P````\``````````````%#"
M````````!P```!```````````````%C"````````!P```!$`````````````
M`&#"````````!P```!(``````````````&C"````````!P```!,`````````
M`````'#"````````!P```!0``````````````'C"````````!P```!4`````
M`````````(#"````````!P```!8``````````````(C"````````!P```!@`
M`````````````)#"````````!P```!H``````````````)C"````````!P``
M`!L``````````````*#"````````!P```!P``````````````*C"````````
M!P```!X``````````````+#"````````!P```!\``````````````+C"````
M````!P```"```````````````,#"````````!P```",``````````````,C"
M````````!P```"0``````````````-#"````````!P```"4`````````````
M`-C"````````!P```"8``````````````.#"````````!P```"<`````````
M`````.C"````````!P```"@``````````````/#"````````!P```"D`````
M`````````/C"````````!P```"H```````````````##````````!P```"L`
M``````````````C#````````!P```"P``````````````!##````````!P``
M`"T``````````````!C#````````!P```"X``````````````"##````````
M!P```"\``````````````"C#````````!P```#```````````````###````
M````!P```#$``````````````#C#````````!P```#(``````````````$##
M````````!P```#,``````````````$C#````````!P```#0`````````````
M`%##````````!P```#4``````````````%C#````````!P```#8`````````
M`````&##````````!P```#<``````````````&C#````````!P```#@`````
M`````````'##````````!P```#D``````````````'C#````````!P```#P`
M`````````````(##````````!P```#T``````````````(C#````````!P``
M`#X``````````````)##````````!P```#\``````````````)C#````````
M!P```$$``````````````*##````````!P```$(``````````````*C#````
M````!P```$,`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!;FC``!(A<!T`O_0Z(4*``#HT$(``$B#Q`C#````````
M``````#_-;*A``#R_R6SH0``#Q\`\P\>^F@`````\NGA____D/,/'OIH`0``
M`/+IT?___Y#S#Q[Z:`(```#RZ<'___^0\P\>^F@#````\NFQ____D/,/'OIH
M!````/+IH?___Y#S#Q[Z:`4```#RZ9'___^0\P\>^F@&````\NF!____D/,/
M'OIH!P```/+I<?___Y#S#Q[Z:`@```#RZ6'___^0\P\>^F@)````\NE1____
MD/,/'OIH"@```/+I0?___Y#S#Q[Z:`L```#RZ3'___^0\P\>^F@,````\NDA
M____D/,/'OIH#0```/+I$?___Y#S#Q[Z:`X```#RZ0'___^0\P\>^F@/````
M\NGQ_O__D/,/'OIH$````/+IX?[__Y#S#Q[Z:!$```#RZ='^__^0\P\>^F@2
M````\NG!_O__D/,/'OIH$P```/+IL?[__Y#S#Q[Z:!0```#RZ:'^__^0\P\>
M^F@5````\NF1_O__D/,/'OIH%@```/+I@?[__Y#S#Q[Z:!<```#RZ7'^__^0
M\P\>^F@8````\NEA_O__D/,/'OIH&0```/+I4?[__Y#S#Q[Z:!H```#RZ4'^
M__^0\P\>^F@;````\NDQ_O__D/,/'OIH'````/+I(?[__Y#S#Q[Z:!T```#R
MZ1'^__^0\P\>^F@>````\ND!_O__D/,/'OIH'P```/+I\?W__Y#S#Q[Z:"``
M``#RZ>']__^0\P\>^F@A````\NG1_?__D/,/'OIH(@```/+IP?W__Y#S#Q[Z
M:",```#RZ;']__^0\P\>^F@D````\NFA_?__D/,/'OIH)0```/+ID?W__Y#S
M#Q[Z:"8```#RZ8']__^0\P\>^F@G````\NEQ_?__D/,/'OIH*````/+I8?W_
M_Y#S#Q[Z:"D```#RZ5']__^0\P\>^F@J````\NE!_?__D/,/'OIH*P```/+I
M,?W__Y#S#Q[Z:"P```#RZ2']__^0\P\>^F@M````\ND1_?__D/,/'OIH+@``
M`/+I`?W__Y#S#Q[Z:"\```#RZ?'\__^0\P\>^F@P````\NGA_/__D/,/'OIH
M,0```/+IT?S__Y#S#Q[Z:#(```#RZ<'\__^0\P\>^F@S````\NFQ_/__D/,/
M'OIH-````/+IH?S__Y#S#Q[Z:#4```#RZ9'\__^0\P\>^F@V````\NF!_/__
MD/,/'OKR_R4EH```#Q]$``#S#Q[Z\O\E+9X```\?1```\P\>^O+_)26>```/
M'T0``/,/'OKR_R4=G@``#Q]$``#S#Q[Z\O\E%9X```\?1```\P\>^O+_)0V>
M```/'T0``/,/'OKR_R4%G@``#Q]$``#S#Q[Z\O\E_9T```\?1```\P\>^O+_
M)?6=```/'T0``/,/'OKR_R7MG0``#Q]$``#S#Q[Z\O\EY9T```\?1```\P\>
M^O+_)=V=```/'T0``/,/'OKR_R75G0``#Q]$``#S#Q[Z\O\ES9T```\?1```
M\P\>^O+_)<6=```/'T0``/,/'OKR_R6]G0``#Q]$``#S#Q[Z\O\EM9T```\?
M1```\P\>^O+_):V=```/'T0``/,/'OKR_R6EG0``#Q]$``#S#Q[Z\O\EG9T`
M``\?1```\P\>^O+_)96=```/'T0``/,/'OKR_R6-G0``#Q]$``#S#Q[Z\O\E
MA9T```\?1```\P\>^O+_)7V=```/'T0``/,/'OKR_R5UG0``#Q]$``#S#Q[Z
M\O\E;9T```\?1```\P\>^O+_)66=```/'T0``/,/'OKR_R5=G0``#Q]$``#S
M#Q[Z\O\E59T```\?1```\P\>^O+_)4V=```/'T0``/,/'OKR_R5%G0``#Q]$
M``#S#Q[Z\O\E/9T```\?1```\P\>^O+_)36=```/'T0``/,/'OKR_R4MG0``
M#Q]$``#S#Q[Z\O\E)9T```\?1```\P\>^O+_)1V=```/'T0``/,/'OKR_R45
MG0``#Q]$``#S#Q[Z\O\E#9T```\?1```\P\>^O+_)06=```/'T0``/,/'OKR
M_R7]G```#Q]$``#S#Q[Z\O\E]9P```\?1```\P\>^O+_)>V<```/'T0``/,/
M'OKR_R7EG```#Q]$``#S#Q[Z\O\EW9P```\?1```\P\>^O+_)=6<```/'T0`
M`/,/'OKR_R7-G```#Q]$``#S#Q[Z\O\EQ9P```\?1```\P\>^O+_);V<```/
M'T0``/,/'OKR_R6UG```#Q]$``#S#Q[Z\O\EK9P```\?1```\P\>^O+_):6<
M```/'T0``/,/'OKR_R6=G```#Q]$``#S#Q[Z\O\EE9P```\?1```\P\>^O+_
M)8V<```/'T0``/,/'OKR_R6%G```#Q]$``#S#Q[Z\O\E?9P```\?1```\P\>
M^D%454B#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E*```
M`$B)1"0H,<#H@____TB+-4R<``!(BSUUG```2(GRZ%T[``!(BP5VG```@#@`
M#X0S`0``3(LE%IP``$&+/"3HO?[__T&+/"2`B"H$```"Z*W^__^`B"H$```!
MBT0D'(UX!$2-8`-(8_](P><#Z*_^__](BTPD$(MT)!Q)B<%(B05TJ```2(L!
M28D!2(T%34D``$F)00A(C04<J```2(L`28E!$$B-!3=)``!)B4$8@_X!#XXR
M`0``2(/!"(/&`[@$````#Q]$``!(BSE(8]"#P`%(@\$(28D\T3G&=>M(8_9(
MBST!J```1(GB13'`2<<$\0````!,B<E(C351&P``Z)S[__]!B<2%P`^$C```
M`$B+/=*G``!(C6PD).A0_?__,<!(B>Y(C3T72```Z$\8``!(A<!T>4B+/:NG
M``#H'OO__^B9_/__2(M$)"AD2"L$)2@````/A:(```!(@\0X1(G@74%<P^@E
M_/__2(D%=J<``$B)QTB%P'1YZ('\__],BR7*F@``08L\).AQ_?__QH#7"0``
M`.F?_O__2(L]1J<``.AY^___08G$Z6#___](BSTZIP``2(7_=`KH$"H``.EQ
M____2(T]+$<``$B)[NBL%P``2(D%%:<``$B)QTB%P`^$3____^O2O@0```#I
MZO[__[\!````Z-/Z___HKOS__V8N#Q^$```````/'T``\P\>^C'M28G17DB)
MXDB#Y/!05$4QP#')2(T]H?W___\5<YH``/1F+@\?A```````2(T]>:8``$B-
M!7*F``!(.?AT%4B+!1::``!(A<!T"?_@#Q^``````,,/'X``````2(T]2:8`
M`$B--4*F``!(*?Y(B?!(P>X_2,'X`T@!QDC1_G042(L%W9D``$B%P'0(_^!F
M#Q]$``###Q^``````/,/'OJ`/06F````=7M52(,]NID```!(B>5!5%-T#$B+
M/=.E``#H=OG__TB-!<^5``!(C1W0E0``2"G#28G$2(L%TZ4``$C!^P-(@^L!
M2#G8<R%F#Q]$``!(@\`!2(D%M:4``$'_%,1(BP6JI0``2#G8<N7H&/___UM!
M7,8%CJ4```%=PP\?0`###Q^``````/,/'OKI)____P\?@`````!!5TB)_DR-
M3SA!5D%505154TB![)@"``!D2(L$)2@```!(B80DB`(``#'`2(GB3(V4)(``
M``!)B=`/'X``````08L!28LY28/`$$F#P0@/R(G`2(GY28E`\$B)^$C!Z2!(
MP>@H2,'O."4`_P``2`GX2(G/2,'A"$C!YQB!X0``_P")_T@)^$@)R$F)0/A-
M.=!UKDB-N@`"```/'X``````2(M":$@S0D!(@\((2#-""$@S0OA(C0P`2,'H
M'T@)R(/@_TB)0GA(.?IUU4R+#DR+7A!(BWX@2(M>&$R)R$R)RDB+;@A(BTPD
M"$C!ZAM(P>`%2`G0`P0D2(V,"YEY@EJ-E#B9>8):3(G82#'82"'H2#'8C3P"
M2(GJ2(GH2,'H`DC!XAY)B?I("<),B=A)P>H;08G03#'`3"'(3#'82`'(2(GY
M2,'A!4P)T4R+5"001(TD"$R)R$R)R4C!Z0)(P>`>3XV4$YEY@EI-B>5("<A)
MP>T;2#'"B<%((?I,,<),`=)-B>))P>(%30GJ3(ML)!A!`=)(B?I(P>\"2,'B
M'D6)TD^-A"B9>8):2`GZ38G52#'0B==,(>!)P>T;2#'(3`'`38G02<'@!4T)
MZ$R+;"0@00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!
MB<1,(=)(,?I(`<I,B<%(P>$%3`GI3(ML)"@!T4R)TDG!Z@)(P>(>B<E*C;PO
MF7F"6DP)TDF)S4@QT$G![1M!B=),(<!,,>!(`?A(B<](P><%3`GO3(ML)#`!
MQTR)P$G!Z`)(P>`>B?]/C:0LF7F"6DP)P$F)_4@QPDG![1M!B<!((<I,,=),
M`>))B?Q)P>0%30GL3(ML)#A!`=1(B<I(P>D"2,'B'D6)Y$^-E"J9>8):2`G*
M38GE2#'02<'M&XG12"'X3#'`3`'038GB2<'B!4T)ZDR+;"1`00'"2(GX2,'O
M`DC!X!Y%B=)/C80HF7F"6D@)^$V)U4@QPDG![1N)QTPAXD@QRDP!PDV)T$G!
MX`5-">A,BVPD2$$!T$R)XDG![`)(P>(>18G`2HV,*9EY@EI,">)-B<5(,=!)
MP>T;08G43"'02#'X2`'(3(G!2,'A!4P)Z4R+;"10`<%,B=!)P>H"2,'@'HG)
M2HV\+YEY@EI,"=!)B<U(,<))P>T;08G"3"'"3#'B2`'Z2(G/2,'G!4P)[TR+
M;"18`==,B<))P>@"2,'B'HG_3XVD+)EY@EI,"<))B?U(,=!)P>T;08G02"'(
M3#'03`'@28G\2<'D!4T)[$R+;"1@00'$2(G(2,'@'DC!Z0)%B>1/C90JF7F"
M6D@)R$V)Y4@QPDG![1N)P4@A^DPQPDP!TDV)XDG!X@5-">I,BVPD:$$!TDB)
M^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=!)P>T;B==,(>!(,<A,`<!-
MB=!)P>`%30GH3(ML)'!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9>8):3`G@38G%
M2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD>`'13(G22,'B'DG!
MZ@*)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!^$B)STC!YP5,
M">],BZPD@`````''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M
M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q&C2PB2(G*2,'I`DR+I"2(````2,'B
M'D@)RD^-E"*9>8):38GL2#'02<'L&XG12"'X3#'`3`'038GJ2<'B!4T)XDR+
MI"20````00'"2(GX2,'@'DC![P)%B=)/C80@F7F"6D@)^$V)U$@QPDG![!N)
MQTPAZD@QRDP!PDV)T$G!X`5-">!%B<!,`<)-B>A)P>T"2<'@'D&)U$T)Z$R+
MK"28````3#'`3"'02HV,*9EY@EI-B>5(,?A)P>T;2`'(3(GA2,'A!4P)Z8G)
M2`'(3(G12<'J`DC!X1Y!B<5,"=%-B<)%B<!),<I$,=),BY0DH````$J-O!>A
MZ]EN38GJ2`'73(GJ2<'J&TC!X@5,"=*)TD@!UTR)XDC!XAY)P>P"08GZ3`.$
M)*@```!,">))B<R)R4@#C"2P````23'41#'@38VD`*'KV6Y,B=!-B=!)P>@;
M2,'@!4P)P(G`20'$3(GH2<'M`DC!X!Y%B>!,">A)B=6)TD@#E"2X````23'%
M1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$
MB>],"=%)B<*)P$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!
MU$R)PDG!Z`)(P>(>18GB3`G"28G(2`.$),````")R4DQT$@#C"3(````13'H
M3HVL`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'%2(GX2,'O`DC!X!Y%B>A(
M"?A(B=>)TD@#E"30````2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)
M^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#A"38````23'*13'J3HVL
M$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))
MB<B)R4DQT$@#C"3@````13'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`
M20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"3H````2#''1#'O3(VL.:'K
MV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)
MP$@#A"3P````23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'4
M3(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02,'@
M!4G!Z!M(`XPD^````$P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#
ME"0``0``2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G1
M2<'J`DC!X1Y$B>=,"=%)B<*)P$@#A"0(`0``23'*13'J3HVL$J'KV6Y(B?I)
MB?I)P>H;2,'B!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$4Q
MX$Z-I`"AZ]EN3(G038G02<'H&TC!X`5,"<!(`XPD$`$``(G`20'$2(GX2,'O
M`DC!X!Y%B>!("?A(B=>)TD@#E"08`0``2#''1#'O3(VL.:'KV6Y,B<%,B<=(
MP>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"0@`0``
M23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!
MXAY%B>),"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")
MP$D!Q4B)^$C!X!Y(P>\"18GH2`.,)"@!``!("?A(B=>)TD@#E"0P`0``2#''
M1#'G38G$2(V,.:'KV6Y,B<=)P>P;2,'G!4P)YTV)U$G!Z@))P>0>B?]-"=1)
MB<)(`?F)P$TQXHG/2`.$)#@!``!%,>I)B?U.C902H>O9;DB)^DG![1M(P>(%
M3`GJ00'23(G"2<'H`DC!XAY%B=),"<)-B>!%B>1),=!)B=9!B=5$,<%-B=!(
MC8P(H>O9;DR)T$G!Z!M(P>`%3`G`1(T$`4B)^4C![P*XW+P;CTC!X1Y("?E)
M"<Z)ST@A^DTAUDD)UDB+E"1``0``2`'"3`'B38G$3`'R38G&2<'D!4G![AM-
M"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"1(
M`0``20'&30'U38GF3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A
M'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+M"10`0``20'&3`'W38GN2`'Z3(GO
M2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,
M"?%,B[0D6`$``$D!QDT!\DF)_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI
M2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),B[0D8`$``$D!QDT!\$V)
MUDP!PDV)T$G!X`5)P>X;30GP00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)
MUTTA[DPAT4P)\4R+M"1H`0``20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)
MB=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4&)RDD)SDTAQDPATDP)\DR+M"1P`0``
M20'&30'U38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,B<)(P>(>2<'H`D6)[4P)
MPD@)T4F)UD&)T$TAUDPAX4P)\4R+M"1X`0``20'&3`'W38GN2`'Y3(GO2<'N
M&TC!YP5,"?=)B=8!STR)X4G![`)(P>$>B?],">%!B<Q)"<Y-(>Y,(>),"?),
MB[0D@`$``$D!QDT!\DF)_DP!TDF)^DG![AM)P>(%30GR00'23(GJ2<'M`DC!
MXAY%B=),">I("=%)B=9!B=5((?E-(>9,"?%,B[0DB`$``$D!QDT!\$V)UDP!
MP4V)T$G![AM)P>`%30GP28G600'(2(GY2,'O`DC!X1Y%B<!("?F)STD)SDTA
MUD@A^DP)\DR+M"20`0``20'&30'T38G&3`'B38G$2<'N&TG!Y`5-"?1!`=1,
MB=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"28`0``20'&
M30'U38GF3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)
MP4&)R$D)SDTAYDPAPDP)\DR+M"2@`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!
MYP5,"?<!UTR)XDG![`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0D
MJ`$``$D!QDT!\DF)_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!
MX1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),B[0DL`$``$D!QDT!\$V)UDP!PDV)
MT$G![AM)P>`%30GP00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPA
MT4P)\4R+M"2X`0``20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,
MB=%)P>H"2,'A'D6)Y$P)T4D)SD&)RDTAQDPATDP)\DR+M"3``0``20'&30'U
M38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,B<))P>@"2,'B'D6)[4P)PD@)T4F)
MT$&)UTTAT$PAX4P)P4R+A"3(`0``20'`3`''38GH2`'Y3(GO2<'H&TC!YP5,
M"<=$C00Y3(GG2<'L`DB)T4C!YQY,">=!B?Q("?E,(>E,(>)("<I(BXPDT`$`
M`$@!P4P!T4V)PD@#A"38`0``2`'*3(G!2<'J&TC!X05,"=&)R4@!RDR)Z4G!
M[0)(P>$>08G23`GI2`G/28G-08G.3"''32'E20G]2HT\.$R)T$R+O"3X`0``
M3`'O38G52,'@!4G![1M,">B)P$@!QTR)P$G!Z`)(P>`>08G]20G`N-;!8LI,
M,<$QT4B+E"3@`0``2`'"3`'B38GL2`'*3(GI2<'L&TC!X05,">%-B=2)R4G!
MY!Y(`<I)P>H"20''30GB38G$B=%%B<!-,=1$,>=,BZ0DZ`$``$D!Q$T!]$F)
MSDP!YTF)S$G![AM)P>0%30GT38GN2<'M`DG!YAY%B>1-"?5,B[0D\`$``$P!
MYT&)_$D!QDT!\$V)UDTQ[D0Q\DV)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!(
MB<I(P>D"2,'B'D6)QD@)RD2)T4V)ZDDQTDP!^4R+O"0``@``1#'738GR2`'/
M3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5
MB=)-,>5,`?E,B[PD$`(``$4QZ$V)U4D!R$R)T4G![1M)`<=(P>$%3`GIB<E)
M`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"0(`@``20'&3`'R38GF23'.1#'W38GN
M2`'73(GJ2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(P>(>08G^20G21(GB28G,
MB<E,`?I-,=1,B[PD(`(``$4QX$V)]$D!T$R)\DG![!M)`<=(P>(%3`GBB=))
M`=!,B>I)P>T"2,'B'D6)Q$P)ZDR+K"08`@``20'%3`'I38G523'51#'O38GE
M2`'/3(GA2<'M&TC!X05,">F)R4@!STR)\4G![@)(P>$>08G]20G.1(G128G2
MB=)-,?),`?E,B[PD,`(``$4QT$V)ZDD!R$R)Z4G!ZAM(P>$%3`G1B<E)`<A,
MB>%(P>$>2<'L`D6)PDD!QTP)X4R+I"0H`@``20'$3`'B38GT23',1#'G38G4
M2`'73(G22<'L&TC!X@5,">*)TD@!UTR)ZDG![0)(P>(>08G\20G51(GR28G.
MB<E-,>Y,`?I,B[PD0`(``$4Q\$V)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!,
MB=))P>H"2,'B'D6)QDP)TDR+E"0X`@``20'"3`'138GJ23'21#'738GR2`'/
M3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5
MB=)-,>5,`?E,B[PD8`(``$4QZ$V)U4D!R$R)T4G![1M(P>$%3`GIB<E)`<A,
MB?%)P>X"2,'A'D6)Q4P)\4R+M"1(`@``20'&3`'R38GF18GD23'.1#'W38GN
M2`'73(GJ2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(P>(>08G^20G22(N4)%`"
M``!(`<))`=1(B<J)R4PQTDD!QT0QPDV)\$D!U$R)\DG!Z!M(P>(%3`G"B=))
M`=1,B>I)P>T"2,'B'D6)X$P)ZDR+K"18`@``20'%3`'I38G523'51#'O38G%
M2`'/3(G!2<'M&TC!X05,">F)R4@!STR)\4G![@)(P>$>08G]20G.1(G128G2
MB=)-,?),`?E,B[PD<`(``$4QXDV)[$P!T4V)ZDG![!M)P>(%30GB38G$18G2
M2<'D'DP!T4G!Z`))`<=-">!,BZ0D:`(``$&)RDD!Q$@#A"1X`@``3`'B38GT
M3`'(33'$1#'G38G42`'73(G22<'L&TC!X@5,">)-B>Q)P>T"2<'D'HG230GE
M18GT38G&2`'733'NB?I-`?Q%B<!$,?%)B=9,`<!-B>A,`>%)B=1)P>X;2<'D
M!4T)]$0!X4V)U$G!Z@))P>0>B<E-">)-,=!$,<=)B<A(`?A(B<](P><%2<'H
M&P'I00':3`G'1`-N($B)3@@!^$R)5AA(B09(B=!(P>H"2,'@'DR);B!("=!$
M`=A(B4802(N$)(@"``!D2"L$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^@P
MY?__05=!5D%505154TB#[`A(A?\/A+$```!(BP6Z@@``3(LH387M#X2>````
M#[8'28G_2(GUA,!T!#P]=55%,?9-BV4`387D="]-8_9,B>L/'P!,B?),B?Y,
MB>?H(N/__X7`=0=#@#PT/71'3(MC"$B#PPA-A>1UVDB#Q`A,B>!;74%<05U!
M7D%?PP\?A```````28G^00^V1@%)@\8!A,!T!#P]=>]%*?[KE0\?@`````!,
M*>M/C60T`4C!^P.)70#KM0\?@`````!%,>3KJ0\?`%5(B?U(@>R@````9$B+
M!"4H````2(F$))@````QP$B)YNAJY/__A<!U-HM4)!B!X@#P``"!^@!```!T
M"('Z`*```'4>O@(```!(B>_HO^3__X7`#Y3`#[;`ZP</'T0``#'`2(N4))@`
M``!D2"L4)2@```!U"4B!Q*````!=P^C=X___9F8N#Q^$``````!FD$%6055!
M5%532('LH````&1(BP0E*````$B)A"28````,<!(A?]T"(`_`$B)_74Q2(N$
M))@```!D2"L$)2@````/A2$!``!(@<2@````6UU!7$%=05[#9BX/'X0`````
M`.B+XO__3(TM6"T``$F)Q$B%P'2[3(GGZ%3D__](A<`/A*,```"`>!,N2(U8
M$W4)@'L!`'3?#Q\`@'@3+@^$G@```$B)[^@FXO__2(G?28G&Z!OB__]!C7P&
M`DAC_^ANX?__28G928GH3(GI28G&2(G'O@$````QP$C'PO_____HC./__TR)
M]TB)YNCQX?__3(GW@_C_=!"+1"08)0#P```]`$```'19Z%3A__],B??HK.'_
M_TR)Y^BTX___2(7`#X5@____#Q\`3(GGZ##C__](B>_H..'__^GR_O__#Q\`
M@'L!+@^%6/___X![`@`/A"#____I2?___P\?@`````#HF_[__^NEZ&3B__\/
M'T``\P\>^E-(BQWT?P``BSOHG>+__XL[Z);B__](BQ47@```2(T-8&L``$B-
M-2LL``!(B<?H^>+__XL[Z'+B__],C06\+0``13')6TB-%6`<``!(B<=,B<%(
MC349+```Z3[A__]F9BX/'X0```````\?`$%6055!5%5(@>P`$```2(,,)`!(
M@^P8NO\/``!D2(L$)2@```!(B80D"!```#'`28GE2(G]28GT2(T]W"L``$R)
M[N@YX?__A<!^58U0_TQC\D*`/#0`#X6$````A=)T0$R)\KXO````3(GOZ(#?
M__](A<!T*TB+!11_``"+..B]X?__3(GQ3(GJ2(GN2(G'Z-S@___K)F8N#Q^$
M``````!(BP7I?@``BSCHDN'__TR)XDB)[DB)Q^CDW___2(N$)`@0``!D2"L$
M)2@```!U&4B!Q!@0``!=05Q!74%>PV:03&/PZ7C____H`^'__P\?`$%7059!
M54%454B)]5-(B?M(@^PH9$B+!"4H````2(E$)!@QP#'`@#X]#Y3`2`'%2(GO
MZ,G?__](C70D%$B)WTF)Q#'`Z(?[__](A<`/A`8!``!(B<=)B<7HH]___TDY
MQ`^&T@```$AC3"043(LU-GX``$R-/,T`````#[8#A,`/A*,!```\/0^$FP$`
M`$B)V`^V4`%(@\`!A-)T!8#Z/77O2"G82)A-BRY*C7P@`NBMWO__30']28E%
M`$B%P'1228L&2(U+`4J+%#@/M@.(`H3`="(\/74-ZQP/'X``````A,!T$0^V
M`4B#P@%(@\$!B`(\/77KQ@(],<!F#Q]$```/MDP%`(A,`@%(@\`!A,EU[TB+
M1"089$@K!"4H````#X47`0``2(/$*%M=05Q!74%>05_##Q]``#'`9@\?1```
M#[94!0!!B%0%`$B#P`&$TG7NZ[T/'T``3(LU27T``$V+!DF#.``/A,,```!,
MB<!%,>UF#Q]$``!(@\`(1(GJ08/%`4B#.`!U[XUR`TAC]DC!Y@.+!9>)``"%
MP'5C2(GW3(E$)`C'!8&)```!````Z*S=__](B<=(A<`/A%'___])8\U(BW0D
M"$R-/,T`````3(GZZ,C>__])B09(B<=!C44!1(EL)!1(F$C'!,<`````Z83^
M__]F+@\?A```````3(G'Z+C?__])B09(B<=(A<`/A/K^__])8\U,C3S-````
M`.NZ#Q]``#'`Z7?^__^^$````$4Q[>E7____Z+_>__]F9BX/'X0```````\?
M0`#S#Q[Z2(/L"$B+!4%\``"+..CJWO__2(L5:WP``$B#Q`A(C0VP9P``2(G'
M2(TU>"@``.E)W___9@\?A```````\P\>^D%455-(@>P`$```2(,,)`!(@>P`
M$```2(,,)`!(@^P@9$B+!"4H````2(F$)!@@```QP$B-K"00$```28GDZ.G<
M__],C0U8*```N@$0``!(B>]!B<!(C0U**```O@$````QP.BDWO__N@`0``!,
MB>9(B>_HA-W__T4QP(7`>"Z->`%(B<-(8__H/]S__TF)P$B%P'082&/;3(GF
M2(G'2(G:Z+;>___&!!@`28G`2(N$)!@@``!D2"L$)2@```!U#TB!Q"`@``!,
MB<!;74%<P^B8W?__#Q^$``````#S#Q[ZZ1?___\/'X``````\P\>^D%7059!
M54%455-(@>P`$```2(,,)`!(@>S(````9$B+!"4H````2(F$)+@0```QP$B)
M_4F)]$B-/8<G``!(C70D'.@%^/__OB\```!(B>](B</HU=S__TB%P'1`,<!(
MB>Y(C3UE)P``Z`_\__](B>A(BY0DN!```&1(*Q0E*`````^%@@$``$B!Q,@0
M``!;74%<05U!7D%?PP\?`$B)[^C8V___3(GG3(TE+"<``$&)QNBFW/__3(GF
M2(G'Z-O<__])B<5(A<!TDT&-1@%!@'T``$R--00H``")1"0,#X3&````9@\?
MA```````2(7;=!-,B>Y(B=_HD-S__X7`#X2$````3(GOZ'#;___K"68/'T0`
M`,8"`(G!@^@!2&/03`'J@#HO=.T#3"0,@?G_#P``#X\E____3(V\)+````!,
MB?%-B>@QP$B#[`BZ`!```+X!````3(G_54R-#7PF``#HM]S__TB-="0P3(G_
MZ!K;__]:687`=1"+1"0X)0#P```]`(```'143(GF,?_H"MS__TF)Q4B%P`^$
MOO[__T&`?0``#X5#____2(7;=`6`.RYT&4R-+0@F``"Y`0```.EC____#Q^$
M``````"`>P$`=+;KWP\?A```````O@$```!,B?_H0]S__X7`=9M,B?Y(C3W6
M)0``Z(#Z__],B?_H6-O__^EG_O__Z&[;__]F9BX/'X0```````\?`/,/'OH/
MM@=)B?B$P'039I!(@\<!/"\/M@=,#T3'A,!U[TR)P,-F9BX/'X0``````/,/
M'OI(A?\/A,,```!5@#\`2(G]#X2>````Z!':__](C50%_T@YU7(0Z9<```!F
MD$B#Z@%(.=5T)8`Z+W3R2#G5#X-^````2(/J`4@YU70.@#HO="A(@^H!2#G5
M=?*`?0`O=%1(C3TE)0``7>F?VO__#Q^``````(`Z+W4)2(/J`4@YU7+R2"GJ
M,<!(C4H"2('Y`!```'<82(/"`;D`$```2(GN2(T]U80``.A0V/__7<-F#Q]$
M``!(C3VW)```7>E+VO__2#G5=;/KD@\?0`!(C3V?)```Z33:__\/'T``\P\>
M^D%7059!54%455-(C1V=)```2(/L2&8/;P5O8P``9$B+!"4H````2(E$)#@Q
MP#'`2(UL)`P/*40D$&8/;P5;8P``9HE$)#`/*40D()`QP$B)[DB)W^C#]/__
M2(7`=#Y(BP6/=P``2&-4)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+
M4!!(@\`(2(D02(72=?#KMF8/'T0``$B-'10D``!F#Q^$```````QP$B)[DB)
MW^AC]/__2(7`=#Y(BP4O=P``2&-4)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^`
M`````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-';PC``!F#Q^$```````Q
MP$B)[DB)W^@#]/__2(7`=#Y(BP7/=@``2&-4)`Q(BP!(C0302(M0"$B)$$B%
MTG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-'64C``!F#Q^$
M```````QP$B)[DB)W^BC\___2(7`=#Y(BP5O=@``2&-4)`Q(BP!(C0302(M0
M"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$R-)0PC
M``!F#Q^$```````QP$B)[DR)Y^A#\___2(7`=#Y(BP4/=@``2&-4)`Q(BP!(
MC0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0`
M`$B-';PB``!F#Q^$```````QP$B)[DB)W^CC\O__2(7`=#Y(BP6O=0``2&-4
M)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#K
MMF8/'T0``$R-+1$B``!F#Q^$```````QP$B)[DR)[^B#\O__2(7`=#Y(BP5/
M=0``2&-4)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D0
M2(72=?#KMF8/'T0``$R-/0@B``!F#Q^$```````QP$B)[DR)_^@C\O__2(7`
M=#Y(BP7O=```2&-4)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(
M@\`(2(D02(72=?#KMF8/'T0``$R--;(A``!F#Q^$```````QP$B)[DR)]^C#
M\?__2(7`=#Y(BP6/=```2&-4)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^`````
M`$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-'5PA``!F#Q^$```````QP$B)
M[DB)W^AC\?__2(7`=#Y(BP4O=```2&-4)`Q(BP!(C0302(M0"$B)$$B%TG3/
M#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-'9H@``!F#Q^$````
M```QP$B)[DB)W^@#\?__2(7`=#Y(BP7/<P``2&-4)`Q(BP!(C0302(M0"$B)
M$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B)[DB-/:,@
M``#HL?#__TB)QDB%P'0*3(GW,<#HS_3__TB)[DB-/9,@```QP.B.\/__2(G&
M2(7`=`Y(C3V/(```,<#HJ/3__TB)[DB-/8D@```QP.AG\/__2(G&2(7`=#I,
MB>\QP.B%]/__,<!(C363(```3(GGZ'3T__](BT0D.&1(*P0E*````'552(/$
M2%M=05Q!74%>05_#2(GN2(T]1B```#'`Z!3P__](B<9(A<!T#$R)_S'`Z#+T
M___KJTBX4$%27T-,14%(.40D(76:9H%\)"E./7612(UT)"OKT^@*U?__9BX/
M'X0``````/,/'OI(@^P89$B+!"4H````2(E$)`B+!>1^``"#^/]T'TB+5"0(
M9$@K%"4H````=49(@\08PV8N#Q^$``````!(C70D!$B-/5,?```QP.A][___
M2(G",<!(A=)T$@^V`CPP#Y7"A,`/E<`/ML`AT(D%BWX``.NJZ(34__\/'T``
M\P\>^DB#[`CHL]3__XG'Z#S3__](A<!T`TB+`$B#Q`C#9F8N#Q^$```````/
M'T``\P\>^D%5051,C25:'P``54B)_4R)YU-(@^P89$B+!"4H````2(E$)`@Q
MP$B-="0$Z.ON__](A<!T"(`X`$B)PW4N2(M$)`AD2"L$)2@````/A;````!(
MB>Y(@\083(GG,<!;74%<05WIX_+__P\?`$B)[DB)Q^A%T___2(7`="!(BT0D
M"&1(*P0E*````'5V2(/$&%M=05Q!7<,/'T0``$B)[^BHTO__2(G?28G%Z)W2
M__])C7P%`NCST?__2(/L"$F)Z+X!````4TC'PO____](B<=)B<5,C0W0'0``
M2(T-S!X``#'`Z`34__]86DB+1"0(9$@K!"4H````=0A,B>[I4____^A%T___
M#Q]$``#S#Q[Z2(/L"+^`````Z([1__^ZB:O-[[G^W+J8OO#ATL-(QP`!(T5G
M2(E0"$B)2!!(QT`8=E0R$$B)<"!(QT`H`````$C'0#``````QT!X`````$B#
MQ`C##Q^$``````#S#Q[Z051)B?Q54TB#[!!D2(L$)2@```!(B40D"#'`Z(SW
M__\/MA!(B<6$TG049I!(@\`!@/HO#[802`]$Z(32=>Z+!9A\``!-A>0/E<.#
M^/]T;87`#Y7`(<.$VW4B2(M$)`AD2"L$)2@````/A8\```!(@\006UU!7,,/
M'T0``$&`/"0`=->Z!````$B--78=``!(B>_HE=#__X7`=;](BT0D"&1(*P0E
M*````'522(/$$$R)YUM=05SI4>[__Y`QP$B-="0$2(T]L1P``.C=[/__2(7`
M=`L/M@"$P'0$/#!U#\<%\WL```````#I;/___\<%Y'L```$```#I6?___^C:
MT?__9BX/'X0``````/,/'OI!5TACPD%628G&055!5$F)_%5(C6\X4TB)\TB#
M[`A(BW<H2(M7,(T,QD@Y\4B)3RA(@](`2,'H'4@!T$B)1S!(8T=XA<`/A>D`
M``!!@_X_#XXG`0``08/N0$6)]T'![P9%C6\!2<'E!DD!W9#S#V\#3(GG2(/#
M0`\110#S#V]+T`\131#S#V]3X`\152#S#V];\`\173#HT=7__TPYZW7,0<'G
M!D4I_DECQDB#^`AR7$F+50!(C4T(2(/A^$F)5"0X28M4!?A(B50%^$@IS4@!
MZ$DI[4B#X/A(@_@(<AA(@^#X,=))BW05`$B)-!%(@\((2#G"<NY%B70D>$B#
MQ`A;74%<05U!7D%?PV:0J`1U=$B%P'3A00^V50!!B%0D.*@"=--!#[=4!?YF
MB50%_NO&#Q]``$&]0````$B-?`4`2(G>02G%13GU10]/[DUC_4R)^NAET?__
M08M$)'A$`>A!B40D>(/X0'623(GG12GN3`'[Z/74___IS_[__TF)W>DC____
M08M5`$&)5"0X08M4!?R)5`7\Z5O___^0\P\>^D%63(UV.$%505152(GU4TB+
M1BA(B?M$BV8H1(MN,$C!Z`.#X#]!#\Q!#\V-2`%(F,9$!CB`2&/!3`'P@_DX
M#XX0`0``OD`````ISG0/,=*)T8/"`<8$"``Y\G+S2(GOZ&C4__]F#^_`#Q%%
M.$G'1C``````00\11A!!#Q%&($2);7!(B>]$B65TZ#[4__](BT4`2(GO2,'H
M&(@#2(M%`$C!Z!"(0P%(BT4`B&,"2(M%`(A#`TB+10A(P>@8B$,$2(M%"$C!
MZ!"(0P5(BT4(B&,&2(M%"(A#!TB+11!(P>@8B$,(2(M%$$C!Z!"(0PE(BT40
MB&,*2(M%$(A#"TB+11A(P>@8B$,,2(M%&$C!Z!"(0PU(BT48B&,.2(M%&(A#
M#TB+12!(P>@8B$,02(M%($C!Z!"(0Q%(BT4@B&,22(M%((A#$UM=05Q!74%>
MZ<O-__\/'P"Z.````#'_*<J#^@AR2HG12,<``````$C'1`CX`````$B-2`A(
M@^'X2"G(`<*#XOB#^@@/@O'^__^#XO@QP(G&@\`(2(D\,3G0<O/IVO[__P\?
MA```````]L($=2.%T@^$Q?[__\8``/;"`@^$N?[__S')9HE,$/[IK?[__P\?
M`,<``````,=$$/P`````Z9?^__\/'T0``/,/'OI!5T%6055!5%533(V<)`"`
M__](@>P`$```2(,,)`!,.=QU[TB![&@!``!,C353&```2(E\)`A(C6PD+$R)
M]TB)[F1(BP0E*````$B)A"18@0``2(T%(QD``$C'1"1@`````$C'A"28````
M`````$C'1"1``````$B)1"102(T%_Q<``$B)1"182(T%AA@``$B)1"1X2(T%
MYA@``$B)A"2`````2(T%B!@``$B)A"2(````2(T%T!@``$B)A"20````2(T%
MJ!@``$B)1"0P2(T%N1@``$B)1"0X,<#H+.C__TB%P'0,@#@`28G$#X6K!```
MZ(;-__^)Q^@/S/__2(7`#X3N`P``3(LH387M#X3B`P``3(GOZ"+,__](C7P`
M`>AXR___10^V10!)B<1%A,!T.DV)YTB-'5L8``"010^VP$R)_TB)V;X!````
M2,?"_____S'`28/%`4F#QP+H>\W__T4/MD4`183`==%(C5PD<$B-/:47``#K
M%`\?`$B+>PA(@\,(2(7_#X1'`0``2(GN,<#H=>?__TF)Q4B%P'3=@#@`=-A(
MB<?H,.C__X7`=,Q,B>_H9,S__TF)P$B%P`^$$`$```\?A```````3(G'3(E$
M)!#H8\O__TR)YTB)P^A8R___1(V\`P0$``!-8_],B?_HI<K__T%43(T-G!8`
M`$B-#907``!)B<5(C054%P``2,?"_____[X!````4$R+1"0@3(GO,<#HK\S_
M_TR)[[[``0``Z!+-__]?05B#^/]U$NC%R___1(L(08/Y$0^%%`,``$B-A"2@
M````3(GO2(G&2(E$)!#H`,S__XG#A<`/A,8```!(BT0D"$V)Z+X!````13'D
M2(T5MQ<``$B+"$B+!8UI``!(BS@QP.BKR?__2(N$)%B!``!D2"L$)2@````/
MA<$%``!(@<1H@0``3(G@6UU!7$%=05Y!7\,/'X``````3(TMH18``#';ZQD/
M'T0``$ACPTR+;,10387M=#M!@'T``'0T3(GO@\,!Z-GF__^%P'3=3(GOZ`W+
M__])B<!(A<`/A;'^__](8\-,BVS$4$V%[77)#Q]``$4QP.F8_O__#Q^$````
M``"+A"2X````)0#P```]`$````^%(____T2+I"2\````Z!S+__]!.<0/A0W_
M__^+A"2X````)?\!```]P`$```^%]O[__TR)_^@4R?__2(GN2(T]SA4``$F)
MQ#'`Z'#E__](B<9(A<`/A#0"``!(BT0D"$B+..@'[?__28G'2(7`#X0;`@``
M3(G_Z'/)__](B<*#^`-^.TB82(TURA4``$B)5"0828U\!_SH8\K__X7`=1](
MBU0D&(/Z!`^$QP,``(U"^TB808`\!R\/A+<#``"0BP4J=```@_C_#X1A`P``
M2(T]N10``(7`#X3)`0``2(TU(A4``#'`2(TMHQ4``.C]Z/__3(T]A14``.BQ
MR/__54C'PO____]-B>A03(T-/A0``+X!````3(GG2(T-4!4``#'`Z&C*__]8
M6NM$#Q]``.B+R?__@S@1=4CH<<C__X/#`4B#[`A-B>A53(T-_Q,``$R)^;X!
M````4TC'PO____],B>=0,<#H),K__TB#Q""^P`$``$R)Y^B#RO__@_C_=*Y,
MB>_H5LC__TR)]TR)YC'`Z%GH__],B>?H`?7__^FQ_?__#Q]``#';2(T]<Q0`
M`.L2#Q]$``!(8\-(BWS$,$B%_W0X2(GN,<"#PP'H[N/__TB%P'3A@#@`=-Q(
MB<?H[,C__TF)Q4B%P`^%UOO__TACPTB+?,0P2(7_=<B_#0```$R-+2`4``#H
M0L?__T&X4P```$F)Q.G)^___2(M$)`A-B>B^`0```$4QY$B-%844``!(BPA(
MBP6;9@``2(LX,<#HN<;__^D)_?__#Q]``$B)Q^A(]/__2(N$)%B!``!D2"L$
M)2@````/A;X"``!(@<1H@0``3(GG6UU!7$%=05Y!7^E(R/__#Q^$``````!(
MBT0D"$R+..G8_?__QP5)<@```````$R)_S'V,<#HG<?__TB-/=42``")Q87`
M#X0:_O__N@(```!(Q\;N____B<?HF<C__TB-G"10`0``N@8```")[TB)WNA"
MQO__@+PD4`$```!U#H"\)%$!``!##X2_`0``,=(Q]HGOZ%_(__^_@````.@U
MQO__2,<``2-%9TF)Q[B)J\WO28E'"$@MB\X25TF)1Q!(!?($&"M)QT<8=E0R
M$$F)1R!)QT<H`````$G'1S``````0<='>`````#K#P\?0`!(B=Y,B?_HK?7_
M_[H`@```2(G>B>_HKL7__XG"A<!_X(GO2(VL)#`!``!(C1VQ$@``Z#+%__],
MB?Y(B>_H%_?__TB-A"3(````3(M\)!!(B40D"`\?1```1`^V10!,B?](B=F^
M`0```$C'PO____\QP$B#Q0%)@\<"Z*K'__],.7PD"'732(T%G1(``,:$),@`
M````4/]T)!A(C0U:$@``38GH3(GG,<"^`0```$R-#301``!(Q\+_____Z&C'
M__]97NE3_?__D$B-/5@1```QP$B)[DB)?"0(Z'KA__](A<`/A$[^__\/M@"$
MP`^$0_[__SPP#X0[_O__QP6$<````0```$B+?"0(Z6C\__](BT0D"$B+4`A(
MA=(/A#C\__](B==(B50D".A;Q?__2(/X`P^&(?S__TB+5"0(2(TULA$``$B-
M?`+\Z$O&__](BU0D"(7`3`]$^NG[^___@+PD4@$``$$/A3/^__^`O"13`0``
M0P^%)?[__X"\)%0!``!(#X47_O__@+PD50$``$4/A0G^__^Z`@```$C'QL;_
M__^)[^A@QO__NBD```!(B=Z)[^@1Q/__2(T%:Q$``%!3Z=3^___HOL7__V9F
M+@\?A```````#Q\`\P\>^D%505154TB#[!A(BQT[8P``9$B+!"4H````2(E$
M)`@QP(L[Z-3%__^+.TB)Q>C*Q?__#[:5L````$B-;"0$2(T]Z@\``$B)[HB0
ML0```#'`Z"?@__](A<!T"8`X,0^$F0$``#'`Z/+J__^+.^B+Q?__N0,```"Z
M`0```$B--<H0``!(B<?HHL/__TF)Q$B%P'0T2(M`$(L[3(LHZ%S%__](C16G
M$```2(G'3(GNZ*K#__])BT0D$$R+($'V1"0.0`^%=@$``(L[Z"_%__^Y`P``
M`+H!````2(TU=1```$B)Q^A&P___28G$2(7`=#I(C3T(#P``2(GN,<#H?=__
M_XL[28G%2(7`#X3_````28M$)!!,BR#HXL3__TR)ZDB)QTR)YN@TP___BSOH
MS<3__[H!````2(TU&A```$B)Q^@IPO__BSM)B<3HK\3__TR)YDB-%1,0``!(
MB<?H_<+__XL[Z);$__](B>Y(C3V$#@``QH"Q`````#'`Z/[>__](B05G;@``
M28G$2(7`=#^^P`$``$R)Y^@BQ?__C5`!@_H!=@F#^!$/A:@```!(BT0D"&1(
M*P0E*`````^%L0```$B#Q!A;74%<05W#9I!(BSTA;@``Z)3U__](B04-;@``
M28G$2(7`=:9(C3T>$```,<#H%\3__P\?@`````"`>`$`#X1D_O__Z5C^__^0
M2(L%X6T``$R+*$F+1"003(L@Z-G#__],B>Y,B>?HCN'__^GU_O__9@\?A```
M````BSOHN</__TR)YDB)Q^A.P___Z7/^__^)P4B+!9AM``!,B>)(C3W.#P``
M2(LP,<#HG,/__^@WP___#Q^``````/,/'OI(BPT=;0``Z5#!___S#Q[Z2(L%
M!5T``$B#^/]T+U5(B>532(T=\UP``$B#[`@/'X``````_]!(BT/X2(/K"$B#
M^/]U\$B+7?C)PV:0PP```/,/'OI(@^P(Z,_&__](@\0(PP``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?
M4$%42`!P87(M`"UE`"TM`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``
M55-%4DY!344`)3`R>``E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S
M)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!
M4CHZ4&%C:V5R.CI615)324].`#$N,#4T```````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE
M87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``````
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#
M+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]
M("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E
M("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL
M96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H
M<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN
M960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N
M=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A
M<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z
M('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E
M;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E
M860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H
M97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@7T9(.PIM>2`D;6%G:6-?<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N
M:U]S:7IE.R`C($Y/5$4Z("1M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D
M8VAU;FM?<VEZ90IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(
M+"`D;6%G:6-?<&]S+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@
M*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U
M9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S
M=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?
M<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D
M4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,[
M"GT*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@
M)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L
M:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*
M96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D
M("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@
M=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D
M9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0IU;FQE<W,@*"1B=68@97$@(E!+7#`P,UPP,#0B*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q
M=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?
M<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I
M*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN
M<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@
M=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E
M=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H
M:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM
M>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>
M+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G
M22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-
M)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS
M:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U
M="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E
M)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE
M;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q
M("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T
M(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I
M('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D
M8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G
M?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D
M7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*
M;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;
M0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@
M/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;
M0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A
M9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I
M;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T
M85]P;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E
M('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[
M)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>
M6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@
M(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*
M)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@
M)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^
M<')I;G0H)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN
M8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)3
M1%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG
M.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D
M?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@
M0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*
M;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@
M("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D
M;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD[
M"GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]
M?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK
M+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X
M="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H
M<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^
M>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I
M*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE
M('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^
M.PIC;&]S92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C
M;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I
M='1E;B!A<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L
M92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N
M86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W
M*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG
M97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A
M8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT
M*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL
M("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD[
M"B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N
M9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF
M9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@
M>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO
M=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B72D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A
M='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I
M<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![
M(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@
M)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@
M>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@
M+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F
M:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E
M<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%
M4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE
M(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM
M?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T
M;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM
M>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^
M:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E
M;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%
M3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#
M86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E
M;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F
M:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U
M;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?
M<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M
M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0
M?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@
M>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'
M3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*
M)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@
M;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%
M)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?
M9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN
M,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP
M*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM
M?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!
M4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%
M3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!4
M14U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D
M14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,
M14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]
M*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T
M:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]
M?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I
M9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*
M?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q
M=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O
M;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE
M("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT[
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````<&5R;'AS:2YC
M````````````````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`!&P,[]````!T```#`</__*`$``$!T__]0`0``4'3__V@!``#`=___>`4`
M``!Z__\0`0``0'O__X`!``!PD?__T`$``$"2__\<`@``T)+__T`"``!`E/__
MA`(``+"4__^@`@``H)7__^`"``#PE___+`,``#"8__]$`P``$)G__X`#```@
MF?__E`,``$";___X`P``<)O__PP$``!0G/__/`0``*"A__^,!```(*+__Z@$
M``!0HO__P`0``&"C__\<!0``P*/__S0%``#0I/__I`4``'"F___P!0``8*C_
M_S`&``#PL/__#`<``'"S__](!P```````!0``````````7I2``%X$`$;#`<(
MD`$``!0````<````Z'C__R8`````1`<0`````"0````T````D&___X`#````
M#A!&#AA*#PMW"(``/QHZ*C,D(@`````4````7````.AR__\0````````````
M```4````=````.!R__]P`P````````````!,````C````+AY__\P%@```$(.
M$(\"20X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.T`4#"!8*#CA!#C!!#BA"
M#B!"#AA"#A!"#@A!"P```$@```#<````F(___\T`````0@X0CP)"#AB.`T(.
M((T$0@XHC`5!#C"&!D$..(,'1`Y``FP*#CA$#C!!#BA"#B!"#AA"#A!"#@A)
M"P`@````*`$``!R0__^#`````$$.$(8"2@ZP`0)Q"@X000X(00M`````3`$`
M`(B0__]L`0```$(.$(X"0@X8C0-"#B",!$$.*(8%00XP@P9'#M`!?@H.,$$.
M*$$.($(.&$(.$$(."$L+`!@```"0`0``M)'__V(`````10X0@P("1`X(```\
M````K`$```B2___M`````$(.$(X"0@X8C0-"#B",!$$.*(8%1PZH($D.P"`"
MOPH.*$$.($(.&$(.$$(."$,+2````.P!``"XDO__00(```!"#A"/`D(.&(X#
M0@X@C01"#BB,!4$.,(8&1`XX@P='#F`#%0$*#CA!#C!!#BA"#B!"#AA"#A!"
M#@A%"Q0````X`@``O)3__S<`````2`X060X(`#@```!0`@``Y)3__]@`````
M1@X0C`)!#AB&`T$.((,$1PZ@($P.H$!)#L!``J<*#B!$#AA!#A!"#@A!"Q``
M``",`@``B)7__PD`````````8````*`"``"$E?__$@(```!&#A"/`D(.&(X#
M0@X@C01"#BB,!4$.,(8&00XX@P='#K@@3`Z`(@)Q"@XX00XP00XH0@X@0@X8
M0@X00@X(1`L"KPZ((DX.D"):#H@B00Z`(@```!`````$`P``0)?__R4`````
M````+````!@#``!<E___W`````!.#A"&`@)>"L8."$P+>0H."$<+2`K&#@A%
M"TL.",8`3````$@#```,F/__1@4```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P=+#H`!`]<$"@XX00XP00XH0@X@0@X80@X00@X(00L````8````
MF`,```R=__]\`````$@.(&T*#@A+"P``%````+0#``!PG?__(0````!(#A!8
M#@@`6````,P#``"(G?__"P$```!&#A"-`D(.&(P#2`X@A@1'#BB#!40.0`)"
M"@XH1@X@00X80@X00@X(2`MD"@XH00X@00X80@X00@X(1@MA#DA)#E!C#DA!
M#D`````4````*`0``#R>__]8`````$@.$`)/#@A`````0`0``(2>__\&`0``
M`$8.$(P"1`X8A@-!#B"#!$0.,`)G"@X@00X800X00@X(1@MS"@X@1`X800X0
M0@X(1@L``"@```"$!```0'+__S("````1@X0C`)!#AB&`T0.4`.$`0H.&$0.
M$$(."$$+2````+`$```DG___GP$```!&#A"/`D4.&(X#10X@C01"#BB,!40.
M,(8&10XX@P='#D`"X0H..$$.,$$.*$(.($(.&$(.$$(."$,+`#P```#\!```
M>*#__^L!````1@X0C@)&#AB-`T(.((P$00XHA@5$#C"#!@,V`0H.*$$.($(.
M&$(.$$(."$@+``#8````/`4``"BB__^""````$8.$(\"0@X8C@-"#B"-!$(.
M*(P%00XPA@9!#CB#!T@,"[B``E$-!T<.H(,"`\\!#JB#`F4.L(,"70ZH@P)"
M#J"#`@*""@XX1`XP00XH0@X@0@X80@X00@X(2`L#>`$.J(,"2PZP@P)>#JB#
M`D$.H(,"7`ZH@P)$#K"#`E`.N(,"2P[`@P)+#J"#`@,&`0H..$0.,$$.*$(.
M($(.&$(.$$(."$T+`VT!#JB#`D0.L(,":`ZH@P)!#J"#`@+]"@ZH@P)!#K"#
M`D4+````.````!@&``#<J?__>0(```!&#A"-`D(.&(P#00X@A@1!#BB#!40.
M0`.Y`0H.*$$.($$.&$(.$$(."$,+$````%0&```@K/__$```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````__________\``````````/__________```````````!
M`````````.4"`````````0````````#U`@````````P``````````"``````
M```-`````````#1C````````]?[_;P````"P`P````````4`````````8`T`
M```````&`````````)`$````````"@````````!V!`````````L`````````
M&``````````5`````````````````````P````````#@P0````````(`````
M````*`4````````4``````````<`````````%P````````!H%`````````<`
M````````&!,````````(`````````%`!````````"0`````````8````````
M`!X`````````"`````````#[__]O``````$```@`````_O__;P````"8$@``
M`````/___V\``````0````````#P__]O`````-81````````^?__;P`````"
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(,``
M````````````````````````````0"````````!0(````````&`@````````
M<"````````"`(````````)`@````````H"````````"P(````````,`@````
M````T"````````#@(````````/`@`````````"$````````0(0```````"`A
M````````,"$```````!`(0```````%`A````````8"$```````!P(0``````
M`(`A````````D"$```````"@(0```````+`A````````P"$```````#0(0``
M`````.`A````````\"$`````````(@```````!`B````````("(````````P
M(@```````$`B````````4"(```````!@(@```````'`B````````@"(`````
M``"0(@```````*`B````````L"(```````#`(@```````-`B````````X"(`
M``````#P(@`````````C````````$",````````@(P```````#`C````````
M0",```````!0(P```````&`C````````<",```````"`(P```````)`C````
M````H",`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````"-````````#_____`````.!R````````
M1T-#.B`H56)U;G1U(#$Q+C(N,"TQ-G5B=6YT=3$I(#$Q+C(N,```+G-H<W1R
M=&%B`"YI;G1E<G``+FYO=&4N9VYU+G!R;W!E<G1Y`"YN;W1E+F=N=2YB=6EL
M9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`
M+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP
M;'0`+FEN:70`+G!L="YG;W0`+G!L="YS96,`+G1E>'0`+F9I;FD`+G)O9&%T
M80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YD>6YA
M;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````````
M````````````````````````````````````````````````````````````
M"P````$````"`````````!@#````````&`,````````<````````````````
M`````0```````````````````!,````'`````@`````````X`P```````#@#
M````````,`````````````````````@````````````````````F````!P``
M``(`````````:`,```````!H`P```````"0````````````````````$````
M````````````````.0````<````"`````````(P#````````C`,````````@
M````````````````````!````````````````````$<```#V__]O`@``````
M``"P`P```````+`#````````W``````````&``````````@`````````````
M``````!1````"P````(`````````D`0```````"0!````````-`(````````
M!P````$````(`````````!@`````````60````,````"`````````&`-````
M````8`T```````!V!````````````````````0```````````````````&$`
M``#___]O`@````````#6$0```````-81````````O``````````&````````
M``(``````````@````````!N````_O__;P(`````````F!(```````"8$@``
M`````(``````````!P````$````(````````````````````?0````0````"
M`````````!@3````````&!,```````!0`0````````8`````````"```````
M```8`````````(<````$````0@````````!H%````````&@4````````*`4`
M```````&````&`````@`````````&`````````"1`````0````8`````````
M`"``````````(````````"4````````````````````$````````````````
M````C`````$````&`````````#`@````````,"````````"``P``````````
M````````$``````````0`````````)<````!````!@````````"P(P``````
M`+`C````````$````````````````````!``````````$`````````"@````
M`0````8`````````P",```````#`(P```````'`#```````````````````0
M`````````!``````````J0````$````&`````````#`G````````,"<`````
M```!/```````````````````$````````````````````*\````!````!@``
M```````T8P```````#1C````````$@````````````````````0`````````
M``````````"U`````0````(``````````'``````````<````````'`_````
M```````````````0````````````````````O0````$````"`````````'"O
M````````<*\```````#T````````````````````!```````````````````
M`,L````!`````@````````!HL````````&BP````````:`8`````````````
M``````@```````````````````#5`````0````,``````````,``````````
MP````````!`````````````````````(````````````````````W`````$`
M```#`````````!#`````````$,`````````0````````````````````"```
M`````````````````.,````&`````P`````````@P````````"#`````````
MP`$````````'``````````@`````````$`````````";`````0````,`````
M````X,$```````#@P0```````#`"```````````````````(``````````@`
M````````[`````$````#``````````#0`````````-`````````@````````
M````````````"````````````````````/(````(`````P`````````@T```
M`````"#0````````0!```````````````````"````````````````````#W
M`````0```#`````````````````````@T````````"8`````````````````
M```!``````````$``````````0````,`````````````````````````1M``
E`````````0```````````````````0``````````````````````
